From c8136497ef6198e6b8a426fc23ccadeefe27ebdb Mon Sep 17 00:00:00 2001
From: Kevinthegreat <92656833+kevinthegreat1@users.noreply.github.com>
Date: Tue, 19 Dec 2023 16:39:45 +0800
Subject: Rename Dungeon Manager
---
.../de/hysky/skyblocker/skyblock/dungeon/secrets/DungeonRoomsDFU.java | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
(limited to 'src/test/java/de/hysky')
diff --git a/src/test/java/de/hysky/skyblocker/skyblock/dungeon/secrets/DungeonRoomsDFU.java b/src/test/java/de/hysky/skyblocker/skyblock/dungeon/secrets/DungeonRoomsDFU.java
index 3d2993cf..d45a2172 100644
--- a/src/test/java/de/hysky/skyblocker/skyblock/dungeon/secrets/DungeonRoomsDFU.java
+++ b/src/test/java/de/hysky/skyblocker/skyblock/dungeon/secrets/DungeonRoomsDFU.java
@@ -21,7 +21,7 @@ import java.util.zip.InflaterInputStream;
* Utility class to convert the old dungeon rooms data from Dungeon Rooms Mod to a new format.
* The new format is similar to DRM's format, but uses ints instead of longs and a custom numeric block id to store the block states.
* The first byte is the x position, the second byte is the y position, the third byte is the z position, and the fourth byte is the custom numeric block id.
* Use {@link DungeonSecrets#NUMERIC_ID} to get the custom numeric block id of a block.
* Run this manually when updating dungeon rooms data with DRM's data in {@code src/test/resources/assets/skyblocker/dungeons/dungeonrooms}.
*/
public class DungeonRoomsDFU {
@@ -131,7 +131,7 @@ public class DungeonRoomsDFU {
if (newId == null) {
newId = ItemIdFix.fromId(oldId / 100);
}
- return x << 24 | y << 16 | z << 8 | DungeonSecrets.NUMERIC_ID.getByte(newId);
+ return x << 24 | y << 16 | z << 8 | DungeonManager.NUMERIC_ID.getByte(newId);
}
private static CompletableFuture save() {
@@ -21,7 +21,7 @@ import java.util.zip.InflaterInputStream;
* The new format is similar to DRM's format, but uses ints instead of longs and a custom numeric block id to store the block states.
* The first byte is the x position, the second byte is the y position, the third byte is the z position, and the fourth byte is the custom numeric block id.
- * Use {@link DungeonSecrets#NUMERIC_ID} to get the custom numeric block id of a block.
+ * Use {@link DungeonManager#NUMERIC_ID} to get the custom numeric block id of a block.
* Run this manually when updating dungeon rooms data with DRM's data in {@code src/test/resources/assets/skyblocker/dungeons/dungeonrooms}.
*/
--
cgit